<?php

namespace Drupal\mdp\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemInterface;

interface MDPItemInterface extends FieldItemInterface{

  /**
   * Set the human-readable 'dates' value separated by a separator.
   *
   * @param mixed $mdp
   *  The human-readable 'dates' value separated by a separator. Example "2020-01-01,2020-01-02,2020-01-03"
   * @param mixed $notify
   *   Whether to notify the parent object of the change. Defaults to TRUE. If a
   *   property is updated from a parent object, set it to FALSE to avoid being
   *   notified again.
   */
  public function setMDP($mdp, $notify = TRUE);

  /**
   * Get the human-readable 'dates' value separated by a separator.
   *
   * @return string
   *   The human-readable 'dates' value separated by a separator. Example "2020-01-01,2020-01-02,2020-01-03"
   */
  public function getMDP();

  /**
   * Sets the format to show the human-readable 'dates'
   *
   * @param mixed $mdp_formatted
   *   The format to show the human-readable 'dates'
   * @param mixed $notify
   *   Whether to notify the parent object of the change. Defaults to TRUE. If a
   *   property is updated from a parent object, set it to FALSE to avoid being
   *   notified again.
   */
  public function setFormatedMDP($mdp_formatted, $notify = TRUE);

  /**
   * Get the format to show the human-readable 'dates'
   *
   * @return string
   *   The format to show the human-readable 'dates'
   */
  public function getFormatedMDP();

  /**
   * Sets each timestamp fo dates selected.
   *
   * @param mixed $mdp_timestamp
   *   The timestamp of each date selected.
   * @param mixed $notify
   *   Whether to notify the parent object of the change. Defaults to TRUE. If a
   *   property is updated from a parent object, set it to FALSE to avoid being
   *   notified again.
   */
  public function setTimestampMDP($mdp_timestamp, $notify = TRUE);

  /**
   * Get the timestamp of each date selected.
   *
   * @return string
   *   The timestamp of each date selected.
   */
  public function getTimestampMDP();
}
